@@ -17,7 +17,7 @@
 #' The sensitivity and specificity of a randomForest classification object.
 #'
 #' @param object an \code{\link[randomForestSRC]{rfsrc}} classification object
-#' @param which.outcome select the classification outcome of interest.
+#' @param which_outcome select the classification outcome of interest.
 #' @param oob use oob estimates (default TRUE)
 #' @param ... extra arguments (not used)
 #'
@@ -31,44 +31,42 @@
 #' ## classification example
 #' ## ------------------------------------------------------------
 #' ## -------- iris data
-#' #rfsrc_iris <- rfsrc(Species ~ ., data = iris)
-#' data(rfsrc_iris, package="ggRandomForests")
+#' rfsrc_iris <- rfsrc(Species ~ ., data = iris)
 #'
 #' # ROC for setosa
-#' gg_dta <- gg_roc(rfsrc_iris, which.outcome=1)
+#' gg_dta <- gg_roc(rfsrc_iris, which_outcome=1)
 #' plot(gg_dta)
 #'
 #' # ROC for versicolor
-#' gg_dta <- gg_roc(rfsrc_iris, which.outcome=2)
+#' gg_dta <- gg_roc(rfsrc_iris, which_outcome=2)
 #' plot(gg_dta)
 #'
 #' # ROC for virginica
-#' gg_dta <- gg_roc(rfsrc_iris, which.outcome=3)
+#' gg_dta <- gg_roc(rfsrc_iris, which_outcome=3)
 #' plot(gg_dta)
 #'
-#'
-## -------- iris data
+#' ## -------- iris data
 #' rf_iris <- randomForest::randomForest(Species ~ ., data = iris)
 #'
 #' # ROC for setosa
-#' gg_dta <- gg_roc(rf_iris, which.outcome=1)
+#' gg_dta <- gg_roc(rf_iris, which_outcome=1)
 #' plot(gg_dta)
 #'
 #' # ROC for versicolor
-#' gg_dta <- gg_roc(rf_iris, which.outcome=2)
+#' gg_dta <- gg_roc(rf_iris, which_outcome=2)
 #' plot(gg_dta)
 #'
 #' # ROC for virginica
-#' gg_dta <- gg_roc(rf_iris, which.outcome=3)
+#' gg_dta <- gg_roc(rf_iris, which_outcome=3)
 #' plot(gg_dta)
 #'
 #'
 #' @aliases gg_roc gg_roc.rfsrc gg_roc.randomForest
 
 #' @export
-gg_roc.rfsrc <- function(object, which.outcome, oob, ...) {
-  if (sum(inherits(object, c("rfsrc", "grow"), TRUE) == c(1, 2)) != 2 &
-      sum(inherits(object, c("rfsrc", "predict"), TRUE) == c(1, 2)) != 2 &
+gg_roc.rfsrc <- function(object, which_outcome, oob, ...) {
+  if (sum(inherits(object, c("rfsrc", "grow"), TRUE) == c(1, 2)) != 2 &&
+      sum(inherits(object, c("rfsrc", "predict"), TRUE) == c(1, 2)) != 2 &&
       !inherits(object, "randomForest")) {
     stop(
       "This function only works for objects of class `(rfsrc, grow)',
@@ -79,10 +77,10 @@ gg_roc.rfsrc <- function(object, which.outcome, oob, ...) {
     stop("gg_roc only works with classification forests")
   }
   
-  # Want to remove the which.outcomes argument to plot ROC for all
+  # Want to remove the which_outcomes argument to plot ROC for all
   # outcomes simultaneously.
-  if (missing(which.outcome))
-    which.outcome <- "all"
+  if (missing(which_outcome))
+    which_outcome <- "all"
   
   if (object$family != "class")
     stop("gg_roc is intended for classification forests only.")
@@ -90,7 +88,7 @@ gg_roc.rfsrc <- function(object, which.outcome, oob, ...) {
   gg_dta <-
     calc_roc(object,
              object$yvar,
-             which.outcome = which.outcome,
+             which_outcome = which_outcome,
              oob = oob)
   #   }
   class(gg_dta) <- c("gg_roc", class(gg_dta))
@@ -98,22 +96,22 @@ gg_roc.rfsrc <- function(object, which.outcome, oob, ...) {
   invisible(gg_dta)
 }
 #' @export
-gg_roc <- function(object, which.outcome, oob, ...) {
+gg_roc <- function(object, which_outcome, oob, ...) {
   UseMethod("gg_roc", object)
 }
 
 #' @export
-gg_roc.randomForest <- function(object, which.outcome, oob, ...) {
+gg_roc.randomForest <- function(object, which_outcome, oob, ...) {
   if (sum(inherits(object, "randomForest", TRUE) == c(1, 2)) != 1)
     stop(
       "This function only works for objects of class `(rfsrc, grow)',
       '(rfsrc, predict)' or 'randomForest."
     )
   
-  # Want to remove the which.outcomes argument to plot ROC for all
+  # Want to remove the which_outcomes argument to plot ROC for all
   # outcomes simultaneously.
-  if (missing(which.outcome))
-    which.outcome <- "all"
+  if (missing(which_outcome))
+    which_outcome <- "all"
   
   
   if (!(object$type == "classification")) {
@@ -123,7 +121,7 @@ gg_roc.randomForest <- function(object, which.outcome, oob, ...) {
   gg_dta <-
     calc_roc(object,
              object$y,
-             which.outcome = which.outcome)
+             which_outcome = which_outcome)
   #   }
   class(gg_dta) <- c("gg_roc", class(gg_dta))
   
