@@ -50,8 +50,7 @@
 #' ## ------------------------------------------------------------
 #' ## -------- iris data
 #' ## iris
-#' #rfsrc_iris <- rfsrc(Species ~., data = iris)
-#' data(rfsrc_iris, package="ggRandomForests")
+#' rfsrc_iris <- rfsrc(Species ~., data = iris)
 #'
 #' gg_dta <- gg_variable(rfsrc_iris)
 #' plot(gg_dta, xvar="Sepal.Width")
@@ -111,18 +110,17 @@
 #' rf_boston <- randomForest::randomForest(medv~., data=Boston)
 #' gg_dta <- gg_variable(rf_boston)
 #' plot(gg_dta)
-#'
+#' plot(gg_dta, panel = TRUE)
 #' ## ------------------------------------------------------------
 #' ## survival examples
 #' ## ------------------------------------------------------------
 #' \dontrun{
 #' ## -------- veteran data
 #' ## survival
-#' # data(veteran, package = "randomForestSRC")
-#' # rfsrc_veteran <- rfsrc(Surv(time,status)~., veteran, nsplit = 10,
-#' #                        ntree = 100)
-#' data(rfsrc_veteran, package="ggRandomForests")
-#'
+#' data(veteran, package = "randomForestSRC")
+#' rfsrc_veteran <- rfsrc(Surv(time,status)~., veteran, nsplit = 10,
+#'                         ntree = 100)
+#'                         
 #' # get the 1 year survival time.
 #' gg_dta <- gg_variable(rfsrc_veteran, time=90)
 #'
@@ -140,8 +138,68 @@
 #' # Generate variable dependence plots for age and diagtime
 #' plot(gg_dta, xvar = "age")
 #' }
+#' \dontrun{
 #' ## -------- pbc data
+#' ## We don't run this because of bootstrap confidence limits
+#' # We need to create this dataset
+#' data(pbc, package = "randomForestSRC",) 
+#' # For whatever reason, the age variable is in days... makes no sense to me
+#' for (ind in seq_len(dim(pbc)[2])) {
+#'  if (!is.factor(pbc[, ind])) {
+#'    if (length(unique(pbc[which(!is.na(pbc[, ind])), ind])) <= 2) {
+#'      if (sum(range(pbc[, ind], na.rm = TRUE) == c(0, 1)) == 2) {
+#'        pbc[, ind] <- as.logical(pbc[, ind])
+#'      }
+#'    }
+#'  } else {
+#'    if (length(unique(pbc[which(!is.na(pbc[, ind])), ind])) <= 2) {
+#'      if (sum(sort(unique(pbc[, ind])) == c(0, 1)) == 2) {
+#'        pbc[, ind] <- as.logical(pbc[, ind])
+#'      }
+#'      if (sum(sort(unique(pbc[, ind])) == c(FALSE, TRUE)) == 2) {
+#'        pbc[, ind] <- as.logical(pbc[, ind])
+#'      }
+#'    }
+#'  }
+#'  if (!is.logical(pbc[, ind]) &
+#'      length(unique(pbc[which(!is.na(pbc[, ind])), ind])) <= 5) {
+#'    pbc[, ind] <- factor(pbc[, ind])
+#'  }
+#' }
+#' #Convert age to years
+#' pbc$age <- pbc$age / 364.24
 #'
+#' pbc$years <- pbc$days / 364.24
+#' pbc <- pbc[, -which(colnames(pbc) == "days")]
+#' pbc$treatment <- as.numeric(pbc$treatment)
+#' pbc$treatment[which(pbc$treatment == 1)] <- "DPCA"
+#' pbc$treatment[which(pbc$treatment == 2)] <- "placebo"
+#' pbc$treatment <- factor(pbc$treatment)
+#' dta_train <- pbc[-which(is.na(pbc$treatment)), ]
+#' # Create a test set from the remaining patients
+#'  pbc_test <- pbc[which(is.na(pbc$treatment)), ]
+#'
+#' #========
+#' # build the forest:
+#' rfsrc_pbc <- randomForestSRC::rfsrc(
+#'   Surv(years, status) ~ .,
+#'  dta_train,
+#'  nsplit = 10,
+#'  na.action = "na.impute",
+#'  forest = TRUE,
+#'  importance = TRUE,
+#'  save.memory = TRUE
+#' )
+#' 
+#' gg_dta <- gg_variable(rfsrc_pbc, time=c(.5, 1, 3))
+#' plot(gg_dta, xvar = "age")
+#' plot(gg_dta, xvar = "trig")
+#'
+#' # Generate coplots
+#' plot(gg_dta, xvar = c("age", "trig"), panel=TRUE, se=FALSE)
+#' 
+#' }
+#' 
 #' @aliases gg_variable gg_variable.rfsrc gg_variable.randomForest
 #' @aliases gg_variable.random
 #' @importFrom stats median
@@ -160,7 +218,7 @@ gg_variable.rfsrc <- function(object,
   time_labels <- arg_list$time_labels
   oob <- if (!is.null(arg_list$oob)) {
     arg_list$oob
-  } else{
+  } else {
     TRUE
   }
   
@@ -192,7 +250,7 @@ gg_variable.rfsrc <- function(object,
               sep = "")
       gg_dta <- cbind(gg_dta, object$predicted.oob)
       
-    } else{
+    } else {
       colnames(object$predicted) <-
         paste("yhat.", colnames(object$predicted),
               sep = "")
@@ -233,7 +291,7 @@ gg_variable.rfsrc <- function(object,
       
       if (is.null(time_labels)) {
         gg_dta_t$time <- time[ind]
-      } else{
+      } else {
         gg_dta_t$time <- time_labels[ind]
       }
       
@@ -254,10 +312,8 @@ gg_variable.randomForest <- function(object,
                                      ...) {
   arg_list <- list(...)
   
-  oob <- if (!is.null(arg_list$oob)) {
-    arg_list$oob
-  } else{
-    TRUE
+  if (!is.null(arg_list$oob)) {
+    arg_list$oob <- FALSE
   }
   
   # Want to also handle a plot.variable where partial!= TRUE
@@ -271,7 +327,7 @@ gg_variable.randomForest <- function(object,
   
   # Remove the response from the data.frame
   rsp <- as.character(object$call$formula)[2]
-  gg_dta <- gg_dta[,-which(colnames(gg_dta) == rsp)]
+  gg_dta <- gg_dta[, -which(colnames(gg_dta) == rsp)]
   
   gg_dta$yhat <- as.vector(object$predicted)
   
