@@ -75,7 +75,7 @@ nelson <-
       survival::Surv(time = data[, interval], event = data[, censor])
     if (is.null(by)) {
       srv_tab <- survival::survfit(srv ~ 1, ...)
-    } else{
+    } else {
       srv_tab <-
         survival::survfit(srv ~ survival::strata(data[, by]), ...)
     }
@@ -142,7 +142,7 @@ nelson <-
     lag_l <- 0
     
     life <- vector("numeric", length = dim(gg_dta)[1])
-    for (ind in 1:dim(gg_dta)[1]) {
+    for (ind in seq_len(dim(gg_dta)[1])) {
       life[ind] <-
         lag_l + delta_t[ind] * (3 * gg_dta[ind, "surv"] - lag_surv[ind]) / 2
       lag_l <- life[ind]
