@@ -3,7 +3,12 @@ context("gg_rfsrc tests")
 
 test_that("gg_rfsrc classifications", {
   ## Load the cached forest
-  data(rfsrc_iris, package = "ggRandomForests")
+  rfsrc_iris <- randomForestSRC::rfsrc(
+    Species ~ .,
+    data = iris,
+    forest = TRUE,
+    importance = TRUE,
+    save.memory = TRUE)
   
   # Test the cached forest type
   expect_is(rfsrc_iris, "rfsrc")
@@ -22,7 +27,7 @@ test_that("gg_rfsrc classifications", {
   expect_equal(ncol(gg_dta), ncol(rfsrc_iris$predicted.oob) + 1)
   
   # Test data is correctly pulled from randomForest obect.
-  expect_equivalent(as.matrix(gg_dta[,-which(colnames(gg_dta) == "y")]),
+  expect_equivalent(as.matrix(gg_dta[, -which(colnames(gg_dta) == "y")]),
                     rfsrc_iris$predicted.oob)
   
   ## Test plotting the gg_error object
@@ -43,17 +48,29 @@ test_that("gg_rfsrc classifications", {
   expect_equal(ncol(gg_dta), ncol(rfsrc_iris$predicted) + 1)
   
   # Test data is correctly pulled from randomForest obect.
-  expect_equivalent(as.matrix(gg_dta[,-which(colnames(gg_dta) == "y")]),
+  expect_equivalent(as.matrix(gg_dta[, -which(colnames(gg_dta) == "y")]),
                     rfsrc_iris$predicted)
   
   rf_iris <- randomForest::randomForest(Species ~ ., data = iris)
-  gg_dta <-gg_rfsrc(rf_iris)
+  gg_dta <- gg_rfsrc(rf_iris)
   
 })
 
 test_that("gg_rfsrc regression", {
+  data(Boston, package = "MASS")
+  boston <- Boston
+  
+  boston$chas <- as.logical(boston$chas)
+  
   ## Load the cached forest
-  data(rfsrc_boston, package = "ggRandomForests")
+  rfsrc_boston <-
+    randomForestSRC::rfsrc(
+      medv ~ .,
+      data = boston,
+      forest = TRUE,
+      importance = TRUE,
+      tree.err = TRUE,
+      save.memory = TRUE)
   
   # Test the cached forest type
   expect_is(rfsrc_boston, "rfsrc")
