@@ -3,7 +3,12 @@ context("gg_roc tests")
 
 test_that("gg_roc classifications", {
   ## Load the cached forest
-  data(rfsrc_iris, package = "ggRandomForests")
+  rfsrc_iris <- randomForestSRC::rfsrc(
+    Species ~ .,
+    data = iris,
+    forest = TRUE,
+    importance = TRUE,
+    save.memory = TRUE)
   
   # Test the cached forest type
   expect_is(rfsrc_iris, "rfsrc")
@@ -12,8 +17,8 @@ test_that("gg_roc classifications", {
   expect_match(rfsrc_iris$family, "class")
   
   ## Create the correct gg_roc object
-  which.outcome <- 1
-  gg_dta <- gg_roc(rfsrc_iris, which.outcome)
+  which_outcome <- 1
+  gg_dta <- gg_roc(rfsrc_iris, which_outcome)
   
   # Test object type
   expect_is(gg_dta, "gg_roc")
@@ -22,7 +27,7 @@ test_that("gg_roc classifications", {
   expect_equal(ncol(gg_dta), 3)
   
   # Test data is correctly pulled from randomForest obect.
-  unts <- sort(unique(rfsrc_iris$predicted.oob[, which.outcome]))
+  unts <- sort(unique(rfsrc_iris$predicted.oob[, which_outcome]))
   
   ## Test plotting the gg_roc object
   gg_obj <- plot.gg_roc(gg_dta)
@@ -31,7 +36,7 @@ test_that("gg_roc classifications", {
   expect_is(gg_obj, "ggplot")
   
   # Try test set prediction.
-  gg_dta <- gg_roc(rfsrc_iris, which.outcome, oob = FALSE)
+  gg_dta <- gg_roc(rfsrc_iris, which_outcome, oob = FALSE)
   # Try test set prediction.
   gg_plt <- plot.gg_roc(rfsrc_iris)
   
@@ -42,7 +47,7 @@ test_that("gg_roc classifications", {
   expect_equal(ncol(gg_dta), 3)
   
   # Test data is correctly pulled from randomForest obect.
-  unts <- sort(unique(rfsrc_iris$predicted[, which.outcome]))
+  unts <- sort(unique(rfsrc_iris$predicted[, which_outcome]))
   
   ## Test plotting the gg_roc object
   gg_obj <- plot.gg_roc(gg_dta)
@@ -66,8 +71,8 @@ test_that("gg_roc randomForest classifications", {
   expect_match(rf_iris$type, "classification")
   
   ## Create the correct gg_roc object
-  which.outcome <- 1
-  gg_dta <- gg_roc(rf_iris, which.outcome)
+  which_outcome <- 1
+  gg_dta <- gg_roc(rf_iris, which_outcome)
   
   # Test object type
   expect_is(gg_dta, "gg_roc")
@@ -79,7 +84,7 @@ test_that("gg_roc randomForest classifications", {
   expect_is(gg_obj, "ggplot")
   
   # Try test set prediction.
-  gg_dta <- gg_roc(rf_iris, which.outcome, oob = FALSE)
+  gg_dta <- gg_roc(rf_iris, which_outcome, oob = FALSE)
   
   # Test object type
   expect_is(gg_dta, "gg_roc")
@@ -98,8 +103,20 @@ test_that("gg_roc randomForest classifications", {
 })
 
 test_that("gg_roc regression", {
+  data(Boston, package = "MASS")
+  boston <- Boston
+  
+  boston$chas <- as.logical(boston$chas)
+  
   ## Load the cached forest
-  data(rfsrc_boston, package = "ggRandomForests")
+  rfsrc_boston <-
+    randomForestSRC::rfsrc(
+      medv ~ .,
+      data = boston,
+      forest = TRUE,
+      importance = TRUE,
+      tree.err = TRUE,
+      save.memory = TRUE)
   
   # Test the cached forest type
   expect_is(rfsrc_boston, "rfsrc")
@@ -114,7 +131,12 @@ test_that("gg_roc regression", {
 })
 
 test_that("calc_roc", {
-  data(rfsrc_iris)
+  rfsrc_iris <- randomForestSRC::rfsrc(
+    Species ~ .,
+    data = iris,
+    forest = TRUE,
+    importance = TRUE,
+    save.memory = TRUE)
   
   # Test the cached forest type
   expect_is(rfsrc_iris, "rfsrc")
@@ -124,7 +146,7 @@ test_that("calc_roc", {
   
   gg_dta <- calc_roc.rfsrc(rfsrc_iris,
                            rfsrc_iris$yvar,
-                           which.outcome = 1,
+                           which_outcome = 1,
                            oob = TRUE)
   
   # Test the cached forest type
@@ -135,7 +157,7 @@ test_that("calc_roc", {
   # Test oob=FALSE
   gg_dta <- calc_roc.rfsrc(rfsrc_iris,
                            rfsrc_iris$yvar,
-                           which.outcome = 1,
+                           which_outcome = 1,
                            oob = FALSE)
   
   # Test the cached forest type
@@ -150,7 +172,7 @@ test_that("calc_roc", {
   # The second outcome.
   gg_dta <- calc_roc.rfsrc(rfsrc_iris,
                            rfsrc_iris$yvar,
-                           which.outcome = 2,
+                           which_outcome = 2,
                            oob = TRUE)
   
   # Test the cached forest type
@@ -165,7 +187,7 @@ test_that("calc_roc", {
   # and the third...
   gg_dta <- calc_roc.rfsrc(rfsrc_iris,
                            rfsrc_iris$yvar,
-                           which.outcome = 3,
+                           which_outcome = 3,
                            oob = TRUE)
   
   # Test the cached forest type
